
/*
 * Copyright 2006 The Android Open Source Project
 *
 * Use of this source code is governed by a BSD-style license that can be
 * found in the LICENSE file.
 */


#ifndef SkSVGTypes_DEFINED
#define SkSVGTypes_DEFINED

enum SkSVGTypes {
    SkSVGType_Circle,
    SkSVGType_ClipPath,
    SkSVGType_Defs,
    SkSVGType_Ellipse,
    SkSVGType_FeColorMatrix,
    SkSVGType_Filter,
    SkSVGType_G,
    SkSVGType_Image,
    SkSVGType_Line,
    SkSVGType_LinearGradient,
    SkSVGType_Mask,
    SkSVGType_Metadata,
    SkSVGType_Path,
    SkSVGType_Polygon,
    SkSVGType_Polyline,
    SkSVGType_RadialGradient,
    SkSVGType_Rect,
    SkSVGType_SVG,
    SkSVGType_Stop,
    SkSVGType_Symbol,
    SkSVGType_Text,
    SkSVGType_Tspan,
    SkSVGType_Unknown,
    SkSVGType_Use
};

#endif // SkSVGTypes_DEFINED
