// IWYU pragma: private, include "nsError.h"
#define NS_OK nsresult::NS_OK
#define NS_ERROR_BASE nsresult::NS_ERROR_BASE
#define NS_ERROR_NOT_INITIALIZED nsresult::NS_ERROR_NOT_INITIALIZED
#define NS_ERROR_ALREADY_INITIALIZED nsresult::NS_ERROR_ALREADY_INITIALIZED
#define NS_ERROR_NOT_IMPLEMENTED nsresult::NS_ERROR_NOT_IMPLEMENTED
#define NS_NOINTERFACE nsresult::NS_NOINTERFACE
#define NS_ERROR_NO_INTERFACE nsresult::NS_ERROR_NO_INTERFACE
#define NS_ERROR_ABORT nsresult::NS_ERROR_ABORT
#define NS_ERROR_FAILURE nsresult::NS_ERROR_FAILURE
#define NS_ERROR_UNEXPECTED nsresult::NS_ERROR_UNEXPECTED
#define NS_ERROR_OUT_OF_MEMORY nsresult::NS_ERROR_OUT_OF_MEMORY
#define NS_ERROR_ILLEGAL_VALUE nsresult::NS_ERROR_ILLEGAL_VALUE
#define NS_ERROR_INVALID_ARG nsresult::NS_ERROR_INVALID_ARG
#define NS_ERROR_INVALID_POINTER nsresult::NS_ERROR_INVALID_POINTER
#define NS_ERROR_NULL_POINTER nsresult::NS_ERROR_NULL_POINTER
#define NS_ERROR_NO_AGGREGATION nsresult::NS_ERROR_NO_AGGREGATION
#define NS_ERROR_NOT_AVAILABLE nsresult::NS_ERROR_NOT_AVAILABLE
#define NS_ERROR_FACTORY_NOT_REGISTERED nsresult::NS_ERROR_FACTORY_NOT_REGISTERED
#define NS_ERROR_FACTORY_REGISTER_AGAIN nsresult::NS_ERROR_FACTORY_REGISTER_AGAIN
#define NS_ERROR_FACTORY_NOT_LOADED nsresult::NS_ERROR_FACTORY_NOT_LOADED
#define NS_ERROR_FACTORY_NO_SIGNATURE_SUPPORT nsresult::NS_ERROR_FACTORY_NO_SIGNATURE_SUPPORT
#define NS_ERROR_FACTORY_EXISTS nsresult::NS_ERROR_FACTORY_EXISTS
#define NS_ERROR_CANNOT_CONVERT_DATA nsresult::NS_ERROR_CANNOT_CONVERT_DATA
#define NS_ERROR_OBJECT_IS_IMMUTABLE nsresult::NS_ERROR_OBJECT_IS_IMMUTABLE
#define NS_ERROR_LOSS_OF_SIGNIFICANT_DATA nsresult::NS_ERROR_LOSS_OF_SIGNIFICANT_DATA
#define NS_ERROR_NOT_SAME_THREAD nsresult::NS_ERROR_NOT_SAME_THREAD
#define NS_ERROR_ILLEGAL_DURING_SHUTDOWN nsresult::NS_ERROR_ILLEGAL_DURING_SHUTDOWN
#define NS_ERROR_SERVICE_NOT_AVAILABLE nsresult::NS_ERROR_SERVICE_NOT_AVAILABLE
#define NS_SUCCESS_LOSS_OF_INSIGNIFICANT_DATA nsresult::NS_SUCCESS_LOSS_OF_INSIGNIFICANT_DATA
#define NS_SUCCESS_INTERRUPTED_TRAVERSE nsresult::NS_SUCCESS_INTERRUPTED_TRAVERSE
#define NS_ERROR_SERVICE_NOT_FOUND nsresult::NS_ERROR_SERVICE_NOT_FOUND
#define NS_ERROR_SERVICE_IN_USE nsresult::NS_ERROR_SERVICE_IN_USE
#define NS_BASE_STREAM_CLOSED nsresult::NS_BASE_STREAM_CLOSED
#define NS_BASE_STREAM_OSERROR nsresult::NS_BASE_STREAM_OSERROR
#define NS_BASE_STREAM_ILLEGAL_ARGS nsresult::NS_BASE_STREAM_ILLEGAL_ARGS
#define NS_BASE_STREAM_NO_CONVERTER nsresult::NS_BASE_STREAM_NO_CONVERTER
#define NS_BASE_STREAM_BAD_CONVERSION nsresult::NS_BASE_STREAM_BAD_CONVERSION
#define NS_BASE_STREAM_WOULD_BLOCK nsresult::NS_BASE_STREAM_WOULD_BLOCK
#define NS_ERROR_GFX_PRINTER_NO_PRINTER_AVAILABLE nsresult::NS_ERROR_GFX_PRINTER_NO_PRINTER_AVAILABLE
#define NS_ERROR_GFX_PRINTER_NAME_NOT_FOUND nsresult::NS_ERROR_GFX_PRINTER_NAME_NOT_FOUND
#define NS_ERROR_GFX_PRINTER_COULD_NOT_OPEN_FILE nsresult::NS_ERROR_GFX_PRINTER_COULD_NOT_OPEN_FILE
#define NS_ERROR_GFX_PRINTER_STARTDOC nsresult::NS_ERROR_GFX_PRINTER_STARTDOC
#define NS_ERROR_GFX_PRINTER_ENDDOC nsresult::NS_ERROR_GFX_PRINTER_ENDDOC
#define NS_ERROR_GFX_PRINTER_STARTPAGE nsresult::NS_ERROR_GFX_PRINTER_STARTPAGE
#define NS_ERROR_GFX_PRINTER_DOC_IS_BUSY nsresult::NS_ERROR_GFX_PRINTER_DOC_IS_BUSY
#define NS_ERROR_GFX_CMAP_MALFORMED nsresult::NS_ERROR_GFX_CMAP_MALFORMED
#define NS_BINDING_SUCCEEDED nsresult::NS_BINDING_SUCCEEDED
#define NS_BINDING_FAILED nsresult::NS_BINDING_FAILED
#define NS_BINDING_ABORTED nsresult::NS_BINDING_ABORTED
#define NS_BINDING_REDIRECTED nsresult::NS_BINDING_REDIRECTED
#define NS_BINDING_RETARGETED nsresult::NS_BINDING_RETARGETED
#define NS_ERROR_MALFORMED_URI nsresult::NS_ERROR_MALFORMED_URI
#define NS_ERROR_IN_PROGRESS nsresult::NS_ERROR_IN_PROGRESS
#define NS_ERROR_NO_CONTENT nsresult::NS_ERROR_NO_CONTENT
#define NS_ERROR_UNKNOWN_PROTOCOL nsresult::NS_ERROR_UNKNOWN_PROTOCOL
#define NS_ERROR_INVALID_CONTENT_ENCODING nsresult::NS_ERROR_INVALID_CONTENT_ENCODING
#define NS_ERROR_CORRUPTED_CONTENT nsresult::NS_ERROR_CORRUPTED_CONTENT
#define NS_ERROR_FIRST_HEADER_FIELD_COMPONENT_EMPTY nsresult::NS_ERROR_FIRST_HEADER_FIELD_COMPONENT_EMPTY
#define NS_ERROR_ALREADY_OPENED nsresult::NS_ERROR_ALREADY_OPENED
#define NS_ERROR_ALREADY_CONNECTED nsresult::NS_ERROR_ALREADY_CONNECTED
#define NS_ERROR_NOT_CONNECTED nsresult::NS_ERROR_NOT_CONNECTED
#define NS_ERROR_CONNECTION_REFUSED nsresult::NS_ERROR_CONNECTION_REFUSED
#define NS_ERROR_NET_TIMEOUT nsresult::NS_ERROR_NET_TIMEOUT
#define NS_ERROR_OFFLINE nsresult::NS_ERROR_OFFLINE
#define NS_ERROR_PORT_ACCESS_NOT_ALLOWED nsresult::NS_ERROR_PORT_ACCESS_NOT_ALLOWED
#define NS_ERROR_NET_RESET nsresult::NS_ERROR_NET_RESET
#define NS_ERROR_NET_INTERRUPT nsresult::NS_ERROR_NET_INTERRUPT
#define NS_ERROR_PROXY_CONNECTION_REFUSED nsresult::NS_ERROR_PROXY_CONNECTION_REFUSED
#define NS_ERROR_NOT_RESUMABLE nsresult::NS_ERROR_NOT_RESUMABLE
#define NS_ERROR_REDIRECT_LOOP nsresult::NS_ERROR_REDIRECT_LOOP
#define NS_ERROR_ENTITY_CHANGED nsresult::NS_ERROR_ENTITY_CHANGED
#define NS_ERROR_UNSAFE_CONTENT_TYPE nsresult::NS_ERROR_UNSAFE_CONTENT_TYPE
#define NS_ERROR_REMOTE_XUL nsresult::NS_ERROR_REMOTE_XUL
#define NS_ERROR_FTP_LOGIN nsresult::NS_ERROR_FTP_LOGIN
#define NS_ERROR_FTP_CWD nsresult::NS_ERROR_FTP_CWD
#define NS_ERROR_FTP_PASV nsresult::NS_ERROR_FTP_PASV
#define NS_ERROR_FTP_PWD nsresult::NS_ERROR_FTP_PWD
#define NS_ERROR_FTP_LIST nsresult::NS_ERROR_FTP_LIST
#define NS_ERROR_UNKNOWN_HOST nsresult::NS_ERROR_UNKNOWN_HOST
#define NS_ERROR_DNS_LOOKUP_QUEUE_FULL nsresult::NS_ERROR_DNS_LOOKUP_QUEUE_FULL
#define NS_ERROR_UNKNOWN_PROXY_HOST nsresult::NS_ERROR_UNKNOWN_PROXY_HOST
#define NS_ERROR_UNKNOWN_SOCKET_TYPE nsresult::NS_ERROR_UNKNOWN_SOCKET_TYPE
#define NS_ERROR_SOCKET_CREATE_FAILED nsresult::NS_ERROR_SOCKET_CREATE_FAILED
#define NS_ERROR_SOCKET_ADDRESS_NOT_SUPPORTED nsresult::NS_ERROR_SOCKET_ADDRESS_NOT_SUPPORTED
#define NS_ERROR_SOCKET_ADDRESS_IN_USE nsresult::NS_ERROR_SOCKET_ADDRESS_IN_USE
#define NS_ERROR_CACHE_KEY_NOT_FOUND nsresult::NS_ERROR_CACHE_KEY_NOT_FOUND
#define NS_ERROR_CACHE_DATA_IS_STREAM nsresult::NS_ERROR_CACHE_DATA_IS_STREAM
#define NS_ERROR_CACHE_DATA_IS_NOT_STREAM nsresult::NS_ERROR_CACHE_DATA_IS_NOT_STREAM
#define NS_ERROR_CACHE_WAIT_FOR_VALIDATION nsresult::NS_ERROR_CACHE_WAIT_FOR_VALIDATION
#define NS_ERROR_CACHE_ENTRY_DOOMED nsresult::NS_ERROR_CACHE_ENTRY_DOOMED
#define NS_ERROR_CACHE_READ_ACCESS_DENIED nsresult::NS_ERROR_CACHE_READ_ACCESS_DENIED
#define NS_ERROR_CACHE_WRITE_ACCESS_DENIED nsresult::NS_ERROR_CACHE_WRITE_ACCESS_DENIED
#define NS_ERROR_CACHE_IN_USE nsresult::NS_ERROR_CACHE_IN_USE
#define NS_ERROR_DOCUMENT_NOT_CACHED nsresult::NS_ERROR_DOCUMENT_NOT_CACHED
#define NS_ERROR_INSUFFICIENT_DOMAIN_LEVELS nsresult::NS_ERROR_INSUFFICIENT_DOMAIN_LEVELS
#define NS_ERROR_HOST_IS_IP_ADDRESS nsresult::NS_ERROR_HOST_IS_IP_ADDRESS
#define NS_SUCCESS_ADOPTED_DATA nsresult::NS_SUCCESS_ADOPTED_DATA
#define NS_NET_STATUS_BEGIN_FTP_TRANSACTION nsresult::NS_NET_STATUS_BEGIN_FTP_TRANSACTION
#define NS_NET_STATUS_END_FTP_TRANSACTION nsresult::NS_NET_STATUS_END_FTP_TRANSACTION
#define NS_SUCCESS_AUTH_FINISHED nsresult::NS_SUCCESS_AUTH_FINISHED
#define NS_NET_STATUS_READING nsresult::NS_NET_STATUS_READING
#define NS_NET_STATUS_WRITING nsresult::NS_NET_STATUS_WRITING
#define NS_NET_STATUS_RESOLVING_HOST nsresult::NS_NET_STATUS_RESOLVING_HOST
#define NS_NET_STATUS_RESOLVED_HOST nsresult::NS_NET_STATUS_RESOLVED_HOST
#define NS_NET_STATUS_CONNECTING_TO nsresult::NS_NET_STATUS_CONNECTING_TO
#define NS_NET_STATUS_CONNECTED_TO nsresult::NS_NET_STATUS_CONNECTED_TO
#define NS_NET_STATUS_SENDING_TO nsresult::NS_NET_STATUS_SENDING_TO
#define NS_NET_STATUS_WAITING_FOR nsresult::NS_NET_STATUS_WAITING_FOR
#define NS_NET_STATUS_RECEIVING_FROM nsresult::NS_NET_STATUS_RECEIVING_FROM
#define NS_ERROR_PLUGINS_PLUGINSNOTCHANGED nsresult::NS_ERROR_PLUGINS_PLUGINSNOTCHANGED
#define NS_ERROR_PLUGIN_DISABLED nsresult::NS_ERROR_PLUGIN_DISABLED
#define NS_ERROR_PLUGIN_BLOCKLISTED nsresult::NS_ERROR_PLUGIN_BLOCKLISTED
#define NS_ERROR_PLUGIN_TIME_RANGE_NOT_SUPPORTED nsresult::NS_ERROR_PLUGIN_TIME_RANGE_NOT_SUPPORTED
#define NS_ERROR_PLUGIN_CLICKTOPLAY nsresult::NS_ERROR_PLUGIN_CLICKTOPLAY
#define NS_TABLELAYOUT_CELL_NOT_FOUND nsresult::NS_TABLELAYOUT_CELL_NOT_FOUND
#define NS_POSITION_BEFORE_TABLE nsresult::NS_POSITION_BEFORE_TABLE
#define NS_STATE_PROPERTY_EXISTS nsresult::NS_STATE_PROPERTY_EXISTS
#define NS_STATE_PROPERTY_NOT_THERE nsresult::NS_STATE_PROPERTY_NOT_THERE
#define NS_ERROR_HTMLPARSER_CONTINUE nsresult::NS_ERROR_HTMLPARSER_CONTINUE
#define NS_ERROR_HTMLPARSER_EOF nsresult::NS_ERROR_HTMLPARSER_EOF
#define NS_ERROR_HTMLPARSER_UNKNOWN nsresult::NS_ERROR_HTMLPARSER_UNKNOWN
#define NS_ERROR_HTMLPARSER_CANTPROPAGATE nsresult::NS_ERROR_HTMLPARSER_CANTPROPAGATE
#define NS_ERROR_HTMLPARSER_CONTEXTMISMATCH nsresult::NS_ERROR_HTMLPARSER_CONTEXTMISMATCH
#define NS_ERROR_HTMLPARSER_BADFILENAME nsresult::NS_ERROR_HTMLPARSER_BADFILENAME
#define NS_ERROR_HTMLPARSER_BADURL nsresult::NS_ERROR_HTMLPARSER_BADURL
#define NS_ERROR_HTMLPARSER_INVALIDPARSERCONTEXT nsresult::NS_ERROR_HTMLPARSER_INVALIDPARSERCONTEXT
#define NS_ERROR_HTMLPARSER_INTERRUPTED nsresult::NS_ERROR_HTMLPARSER_INTERRUPTED
#define NS_ERROR_HTMLPARSER_BLOCK nsresult::NS_ERROR_HTMLPARSER_BLOCK
#define NS_ERROR_HTMLPARSER_BADTOKENIZER nsresult::NS_ERROR_HTMLPARSER_BADTOKENIZER
#define NS_ERROR_HTMLPARSER_BADATTRIBUTE nsresult::NS_ERROR_HTMLPARSER_BADATTRIBUTE
#define NS_ERROR_HTMLPARSER_UNRESOLVEDDTD nsresult::NS_ERROR_HTMLPARSER_UNRESOLVEDDTD
#define NS_ERROR_HTMLPARSER_MISPLACEDTABLECONTENT nsresult::NS_ERROR_HTMLPARSER_MISPLACEDTABLECONTENT
#define NS_ERROR_HTMLPARSER_BADDTD nsresult::NS_ERROR_HTMLPARSER_BADDTD
#define NS_ERROR_HTMLPARSER_BADCONTEXT nsresult::NS_ERROR_HTMLPARSER_BADCONTEXT
#define NS_ERROR_HTMLPARSER_STOPPARSING nsresult::NS_ERROR_HTMLPARSER_STOPPARSING
#define NS_ERROR_HTMLPARSER_UNTERMINATEDSTRINGLITERAL nsresult::NS_ERROR_HTMLPARSER_UNTERMINATEDSTRINGLITERAL
#define NS_ERROR_HTMLPARSER_HIERARCHYTOODEEP nsresult::NS_ERROR_HTMLPARSER_HIERARCHYTOODEEP
#define NS_ERROR_HTMLPARSER_FAKE_ENDTAG nsresult::NS_ERROR_HTMLPARSER_FAKE_ENDTAG
#define NS_ERROR_HTMLPARSER_INVALID_COMMENT nsresult::NS_ERROR_HTMLPARSER_INVALID_COMMENT
#define NS_HTMLTOKENS_NOT_AN_ENTITY nsresult::NS_HTMLTOKENS_NOT_AN_ENTITY
#define NS_HTMLPARSER_VALID_META_CHARSET nsresult::NS_HTMLPARSER_VALID_META_CHARSET
#define NS_RDF_ASSERTION_ACCEPTED nsresult::NS_RDF_ASSERTION_ACCEPTED
#define NS_RDF_CURSOR_EMPTY nsresult::NS_RDF_CURSOR_EMPTY
#define NS_RDF_NO_VALUE nsresult::NS_RDF_NO_VALUE
#define NS_RDF_ASSERTION_REJECTED nsresult::NS_RDF_ASSERTION_REJECTED
#define NS_RDF_STOP_VISIT nsresult::NS_RDF_STOP_VISIT
#define NS_ERROR_UCONV_NOCONV nsresult::NS_ERROR_UCONV_NOCONV
#define NS_ERROR_UDEC_ILLEGALINPUT nsresult::NS_ERROR_UDEC_ILLEGALINPUT
#define NS_SUCCESS_USING_FALLBACK_LOCALE nsresult::NS_SUCCESS_USING_FALLBACK_LOCALE
#define NS_OK_UDEC_EXACTLENGTH nsresult::NS_OK_UDEC_EXACTLENGTH
#define NS_OK_UDEC_MOREINPUT nsresult::NS_OK_UDEC_MOREINPUT
#define NS_OK_UDEC_MOREOUTPUT nsresult::NS_OK_UDEC_MOREOUTPUT
#define NS_OK_UDEC_NOBOMFOUND nsresult::NS_OK_UDEC_NOBOMFOUND
#define NS_OK_UENC_EXACTLENGTH nsresult::NS_OK_UENC_EXACTLENGTH
#define NS_OK_UENC_MOREOUTPUT nsresult::NS_OK_UENC_MOREOUTPUT
#define NS_ERROR_UENC_NOMAPPING nsresult::NS_ERROR_UENC_NOMAPPING
#define NS_OK_UENC_MOREINPUT nsresult::NS_OK_UENC_MOREINPUT
#define NS_EXACT_LENGTH nsresult::NS_EXACT_LENGTH
#define NS_PARTIAL_MORE_INPUT nsresult::NS_PARTIAL_MORE_INPUT
#define NS_PARTIAL_MORE_OUTPUT nsresult::NS_PARTIAL_MORE_OUTPUT
#define NS_ERROR_ILLEGAL_INPUT nsresult::NS_ERROR_ILLEGAL_INPUT
#define NS_ERROR_FILE_UNRECOGNIZED_PATH nsresult::NS_ERROR_FILE_UNRECOGNIZED_PATH
#define NS_ERROR_FILE_UNRESOLVABLE_SYMLINK nsresult::NS_ERROR_FILE_UNRESOLVABLE_SYMLINK
#define NS_ERROR_FILE_EXECUTION_FAILED nsresult::NS_ERROR_FILE_EXECUTION_FAILED
#define NS_ERROR_FILE_UNKNOWN_TYPE nsresult::NS_ERROR_FILE_UNKNOWN_TYPE
#define NS_ERROR_FILE_DESTINATION_NOT_DIR nsresult::NS_ERROR_FILE_DESTINATION_NOT_DIR
#define NS_ERROR_FILE_TARGET_DOES_NOT_EXIST nsresult::NS_ERROR_FILE_TARGET_DOES_NOT_EXIST
#define NS_ERROR_FILE_COPY_OR_MOVE_FAILED nsresult::NS_ERROR_FILE_COPY_OR_MOVE_FAILED
#define NS_ERROR_FILE_ALREADY_EXISTS nsresult::NS_ERROR_FILE_ALREADY_EXISTS
#define NS_ERROR_FILE_INVALID_PATH nsresult::NS_ERROR_FILE_INVALID_PATH
#define NS_ERROR_FILE_DISK_FULL nsresult::NS_ERROR_FILE_DISK_FULL
#define NS_ERROR_FILE_CORRUPTED nsresult::NS_ERROR_FILE_CORRUPTED
#define NS_ERROR_FILE_NOT_DIRECTORY nsresult::NS_ERROR_FILE_NOT_DIRECTORY
#define NS_ERROR_FILE_IS_DIRECTORY nsresult::NS_ERROR_FILE_IS_DIRECTORY
#define NS_ERROR_FILE_IS_LOCKED nsresult::NS_ERROR_FILE_IS_LOCKED
#define NS_ERROR_FILE_TOO_BIG nsresult::NS_ERROR_FILE_TOO_BIG
#define NS_ERROR_FILE_NO_DEVICE_SPACE nsresult::NS_ERROR_FILE_NO_DEVICE_SPACE
#define NS_ERROR_FILE_NAME_TOO_LONG nsresult::NS_ERROR_FILE_NAME_TOO_LONG
#define NS_ERROR_FILE_NOT_FOUND nsresult::NS_ERROR_FILE_NOT_FOUND
#define NS_ERROR_FILE_READ_ONLY nsresult::NS_ERROR_FILE_READ_ONLY
#define NS_ERROR_FILE_DIR_NOT_EMPTY nsresult::NS_ERROR_FILE_DIR_NOT_EMPTY
#define NS_ERROR_FILE_ACCESS_DENIED nsresult::NS_ERROR_FILE_ACCESS_DENIED
#define NS_SUCCESS_FILE_DIRECTORY_EMPTY nsresult::NS_SUCCESS_FILE_DIRECTORY_EMPTY
#define NS_SUCCESS_AGGREGATE_RESULT nsresult::NS_SUCCESS_AGGREGATE_RESULT
#define NS_ERROR_DOM_INDEX_SIZE_ERR nsresult::NS_ERROR_DOM_INDEX_SIZE_ERR
#define NS_ERROR_DOM_HIERARCHY_REQUEST_ERR nsresult::NS_ERROR_DOM_HIERARCHY_REQUEST_ERR
#define NS_ERROR_DOM_WRONG_DOCUMENT_ERR nsresult::NS_ERROR_DOM_WRONG_DOCUMENT_ERR
#define NS_ERROR_DOM_INVALID_CHARACTER_ERR nsresult::NS_ERROR_DOM_INVALID_CHARACTER_ERR
#define NS_ERROR_DOM_NO_MODIFICATION_ALLOWED_ERR nsresult::NS_ERROR_DOM_NO_MODIFICATION_ALLOWED_ERR
#define NS_ERROR_DOM_NOT_FOUND_ERR nsresult::NS_ERROR_DOM_NOT_FOUND_ERR
#define NS_ERROR_DOM_NOT_SUPPORTED_ERR nsresult::NS_ERROR_DOM_NOT_SUPPORTED_ERR
#define NS_ERROR_DOM_INUSE_ATTRIBUTE_ERR nsresult::NS_ERROR_DOM_INUSE_ATTRIBUTE_ERR
#define NS_ERROR_DOM_INVALID_STATE_ERR nsresult::NS_ERROR_DOM_INVALID_STATE_ERR
#define NS_ERROR_DOM_SYNTAX_ERR nsresult::NS_ERROR_DOM_SYNTAX_ERR
#define NS_ERROR_DOM_INVALID_MODIFICATION_ERR nsresult::NS_ERROR_DOM_INVALID_MODIFICATION_ERR
#define NS_ERROR_DOM_NAMESPACE_ERR nsresult::NS_ERROR_DOM_NAMESPACE_ERR
#define NS_ERROR_DOM_INVALID_ACCESS_ERR nsresult::NS_ERROR_DOM_INVALID_ACCESS_ERR
#define NS_ERROR_DOM_TYPE_MISMATCH_ERR nsresult::NS_ERROR_DOM_TYPE_MISMATCH_ERR
#define NS_ERROR_DOM_SECURITY_ERR nsresult::NS_ERROR_DOM_SECURITY_ERR
#define NS_ERROR_DOM_NETWORK_ERR nsresult::NS_ERROR_DOM_NETWORK_ERR
#define NS_ERROR_DOM_ABORT_ERR nsresult::NS_ERROR_DOM_ABORT_ERR
#define NS_ERROR_DOM_URL_MISMATCH_ERR nsresult::NS_ERROR_DOM_URL_MISMATCH_ERR
#define NS_ERROR_DOM_QUOTA_EXCEEDED_ERR nsresult::NS_ERROR_DOM_QUOTA_EXCEEDED_ERR
#define NS_ERROR_DOM_TIMEOUT_ERR nsresult::NS_ERROR_DOM_TIMEOUT_ERR
#define NS_ERROR_DOM_INVALID_NODE_TYPE_ERR nsresult::NS_ERROR_DOM_INVALID_NODE_TYPE_ERR
#define NS_ERROR_DOM_DATA_CLONE_ERR nsresult::NS_ERROR_DOM_DATA_CLONE_ERR
#define NS_ERROR_TYPE_ERR nsresult::NS_ERROR_TYPE_ERR
#define NS_ERROR_RANGE_ERR nsresult::NS_ERROR_RANGE_ERR
#define NS_ERROR_DOM_ENCODING_NOT_SUPPORTED_ERR nsresult::NS_ERROR_DOM_ENCODING_NOT_SUPPORTED_ERR
#define NS_ERROR_DOM_ENCODING_NOT_UTF_ERR nsresult::NS_ERROR_DOM_ENCODING_NOT_UTF_ERR
#define NS_ERROR_DOM_ENCODING_DECODE_ERR nsresult::NS_ERROR_DOM_ENCODING_DECODE_ERR
#define NS_ERROR_DOM_INVALID_POINTER_ERR nsresult::NS_ERROR_DOM_INVALID_POINTER_ERR
#define NS_ERROR_DOM_SECMAN_ERR nsresult::NS_ERROR_DOM_SECMAN_ERR
#define NS_ERROR_DOM_WRONG_TYPE_ERR nsresult::NS_ERROR_DOM_WRONG_TYPE_ERR
#define NS_ERROR_DOM_NOT_OBJECT_ERR nsresult::NS_ERROR_DOM_NOT_OBJECT_ERR
#define NS_ERROR_DOM_NOT_XPC_OBJECT_ERR nsresult::NS_ERROR_DOM_NOT_XPC_OBJECT_ERR
#define NS_ERROR_DOM_NOT_NUMBER_ERR nsresult::NS_ERROR_DOM_NOT_NUMBER_ERR
#define NS_ERROR_DOM_NOT_BOOLEAN_ERR nsresult::NS_ERROR_DOM_NOT_BOOLEAN_ERR
#define NS_ERROR_DOM_NOT_FUNCTION_ERR nsresult::NS_ERROR_DOM_NOT_FUNCTION_ERR
#define NS_ERROR_DOM_TOO_FEW_PARAMETERS_ERR nsresult::NS_ERROR_DOM_TOO_FEW_PARAMETERS_ERR
#define NS_ERROR_DOM_BAD_DOCUMENT_DOMAIN nsresult::NS_ERROR_DOM_BAD_DOCUMENT_DOMAIN
#define NS_ERROR_DOM_PROP_ACCESS_DENIED nsresult::NS_ERROR_DOM_PROP_ACCESS_DENIED
#define NS_ERROR_DOM_XPCONNECT_ACCESS_DENIED nsresult::NS_ERROR_DOM_XPCONNECT_ACCESS_DENIED
#define NS_ERROR_DOM_BAD_URI nsresult::NS_ERROR_DOM_BAD_URI
#define NS_ERROR_DOM_RETVAL_UNDEFINED nsresult::NS_ERROR_DOM_RETVAL_UNDEFINED
#define NS_ERROR_DOM_QUOTA_REACHED nsresult::NS_ERROR_DOM_QUOTA_REACHED
#define NS_ERROR_DOM_JS_EXCEPTION nsresult::NS_ERROR_DOM_JS_EXCEPTION
#define NS_SUCCESS_DOM_NO_OPERATION nsresult::NS_SUCCESS_DOM_NO_OPERATION
#define NS_IMAGELIB_SUCCESS_LOAD_FINISHED nsresult::NS_IMAGELIB_SUCCESS_LOAD_FINISHED
#define NS_IMAGELIB_CHANGING_OWNER nsresult::NS_IMAGELIB_CHANGING_OWNER
#define NS_IMAGELIB_ERROR_FAILURE nsresult::NS_IMAGELIB_ERROR_FAILURE
#define NS_IMAGELIB_ERROR_NO_DECODER nsresult::NS_IMAGELIB_ERROR_NO_DECODER
#define NS_IMAGELIB_ERROR_NOT_FINISHED nsresult::NS_IMAGELIB_ERROR_NOT_FINISHED
#define NS_IMAGELIB_ERROR_NO_ENCODER nsresult::NS_IMAGELIB_ERROR_NO_ENCODER
#define NS_ERROR_EDITOR_NO_SELECTION nsresult::NS_ERROR_EDITOR_NO_SELECTION
#define NS_ERROR_EDITOR_NO_TEXTNODE nsresult::NS_ERROR_EDITOR_NO_TEXTNODE
#define NS_FOUND_TARGET nsresult::NS_FOUND_TARGET
#define NS_EDITOR_ELEMENT_NOT_FOUND nsresult::NS_EDITOR_ELEMENT_NOT_FOUND
#define NS_ERROR_XPC_NOT_ENOUGH_ARGS nsresult::NS_ERROR_XPC_NOT_ENOUGH_ARGS
#define NS_ERROR_XPC_NEED_OUT_OBJECT nsresult::NS_ERROR_XPC_NEED_OUT_OBJECT
#define NS_ERROR_XPC_CANT_SET_OUT_VAL nsresult::NS_ERROR_XPC_CANT_SET_OUT_VAL
#define NS_ERROR_XPC_NATIVE_RETURNED_FAILURE nsresult::NS_ERROR_XPC_NATIVE_RETURNED_FAILURE
#define NS_ERROR_XPC_CANT_GET_INTERFACE_INFO nsresult::NS_ERROR_XPC_CANT_GET_INTERFACE_INFO
#define NS_ERROR_XPC_CANT_GET_PARAM_IFACE_INFO nsresult::NS_ERROR_XPC_CANT_GET_PARAM_IFACE_INFO
#define NS_ERROR_XPC_CANT_GET_METHOD_INFO nsresult::NS_ERROR_XPC_CANT_GET_METHOD_INFO
#define NS_ERROR_XPC_UNEXPECTED nsresult::NS_ERROR_XPC_UNEXPECTED
#define NS_ERROR_XPC_BAD_CONVERT_JS nsresult::NS_ERROR_XPC_BAD_CONVERT_JS
#define NS_ERROR_XPC_BAD_CONVERT_NATIVE nsresult::NS_ERROR_XPC_BAD_CONVERT_NATIVE
#define NS_ERROR_XPC_BAD_CONVERT_JS_NULL_REF nsresult::NS_ERROR_XPC_BAD_CONVERT_JS_NULL_REF
#define NS_ERROR_XPC_BAD_OP_ON_WN_PROTO nsresult::NS_ERROR_XPC_BAD_OP_ON_WN_PROTO
#define NS_ERROR_XPC_CANT_CONVERT_WN_TO_FUN nsresult::NS_ERROR_XPC_CANT_CONVERT_WN_TO_FUN
#define NS_ERROR_XPC_CANT_DEFINE_PROP_ON_WN nsresult::NS_ERROR_XPC_CANT_DEFINE_PROP_ON_WN
#define NS_ERROR_XPC_CANT_WATCH_WN_STATIC nsresult::NS_ERROR_XPC_CANT_WATCH_WN_STATIC
#define NS_ERROR_XPC_CANT_EXPORT_WN_STATIC nsresult::NS_ERROR_XPC_CANT_EXPORT_WN_STATIC
#define NS_ERROR_XPC_SCRIPTABLE_CALL_FAILED nsresult::NS_ERROR_XPC_SCRIPTABLE_CALL_FAILED
#define NS_ERROR_XPC_SCRIPTABLE_CTOR_FAILED nsresult::NS_ERROR_XPC_SCRIPTABLE_CTOR_FAILED
#define NS_ERROR_XPC_CANT_CALL_WO_SCRIPTABLE nsresult::NS_ERROR_XPC_CANT_CALL_WO_SCRIPTABLE
#define NS_ERROR_XPC_CANT_CTOR_WO_SCRIPTABLE nsresult::NS_ERROR_XPC_CANT_CTOR_WO_SCRIPTABLE
#define NS_ERROR_XPC_CI_RETURNED_FAILURE nsresult::NS_ERROR_XPC_CI_RETURNED_FAILURE
#define NS_ERROR_XPC_GS_RETURNED_FAILURE nsresult::NS_ERROR_XPC_GS_RETURNED_FAILURE
#define NS_ERROR_XPC_BAD_CID nsresult::NS_ERROR_XPC_BAD_CID
#define NS_ERROR_XPC_BAD_IID nsresult::NS_ERROR_XPC_BAD_IID
#define NS_ERROR_XPC_CANT_CREATE_WN nsresult::NS_ERROR_XPC_CANT_CREATE_WN
#define NS_ERROR_XPC_JS_THREW_EXCEPTION nsresult::NS_ERROR_XPC_JS_THREW_EXCEPTION
#define NS_ERROR_XPC_JS_THREW_NATIVE_OBJECT nsresult::NS_ERROR_XPC_JS_THREW_NATIVE_OBJECT
#define NS_ERROR_XPC_JS_THREW_JS_OBJECT nsresult::NS_ERROR_XPC_JS_THREW_JS_OBJECT
#define NS_ERROR_XPC_JS_THREW_NULL nsresult::NS_ERROR_XPC_JS_THREW_NULL
#define NS_ERROR_XPC_JS_THREW_STRING nsresult::NS_ERROR_XPC_JS_THREW_STRING
#define NS_ERROR_XPC_JS_THREW_NUMBER nsresult::NS_ERROR_XPC_JS_THREW_NUMBER
#define NS_ERROR_XPC_JAVASCRIPT_ERROR nsresult::NS_ERROR_XPC_JAVASCRIPT_ERROR
#define NS_ERROR_XPC_JAVASCRIPT_ERROR_WITH_DETAILS nsresult::NS_ERROR_XPC_JAVASCRIPT_ERROR_WITH_DETAILS
#define NS_ERROR_XPC_CANT_CONVERT_PRIMITIVE_TO_ARRAY nsresult::NS_ERROR_XPC_CANT_CONVERT_PRIMITIVE_TO_ARRAY
#define NS_ERROR_XPC_CANT_CONVERT_OBJECT_TO_ARRAY nsresult::NS_ERROR_XPC_CANT_CONVERT_OBJECT_TO_ARRAY
#define NS_ERROR_XPC_NOT_ENOUGH_ELEMENTS_IN_ARRAY nsresult::NS_ERROR_XPC_NOT_ENOUGH_ELEMENTS_IN_ARRAY
#define NS_ERROR_XPC_CANT_GET_ARRAY_INFO nsresult::NS_ERROR_XPC_CANT_GET_ARRAY_INFO
#define NS_ERROR_XPC_NOT_ENOUGH_CHARS_IN_STRING nsresult::NS_ERROR_XPC_NOT_ENOUGH_CHARS_IN_STRING
#define NS_ERROR_XPC_SECURITY_MANAGER_VETO nsresult::NS_ERROR_XPC_SECURITY_MANAGER_VETO
#define NS_ERROR_XPC_INTERFACE_NOT_SCRIPTABLE nsresult::NS_ERROR_XPC_INTERFACE_NOT_SCRIPTABLE
#define NS_ERROR_XPC_INTERFACE_NOT_FROM_NSISUPPORTS nsresult::NS_ERROR_XPC_INTERFACE_NOT_FROM_NSISUPPORTS
#define NS_ERROR_XPC_CANT_GET_JSOBJECT_OF_DOM_OBJECT nsresult::NS_ERROR_XPC_CANT_GET_JSOBJECT_OF_DOM_OBJECT
#define NS_ERROR_XPC_CANT_SET_READ_ONLY_CONSTANT nsresult::NS_ERROR_XPC_CANT_SET_READ_ONLY_CONSTANT
#define NS_ERROR_XPC_CANT_SET_READ_ONLY_ATTRIBUTE nsresult::NS_ERROR_XPC_CANT_SET_READ_ONLY_ATTRIBUTE
#define NS_ERROR_XPC_CANT_SET_READ_ONLY_METHOD nsresult::NS_ERROR_XPC_CANT_SET_READ_ONLY_METHOD
#define NS_ERROR_XPC_CANT_ADD_PROP_TO_WRAPPED_NATIVE nsresult::NS_ERROR_XPC_CANT_ADD_PROP_TO_WRAPPED_NATIVE
#define NS_ERROR_XPC_CALL_TO_SCRIPTABLE_FAILED nsresult::NS_ERROR_XPC_CALL_TO_SCRIPTABLE_FAILED
#define NS_ERROR_XPC_JSOBJECT_HAS_NO_FUNCTION_NAMED nsresult::NS_ERROR_XPC_JSOBJECT_HAS_NO_FUNCTION_NAMED
#define NS_ERROR_XPC_BAD_ID_STRING nsresult::NS_ERROR_XPC_BAD_ID_STRING
#define NS_ERROR_XPC_BAD_INITIALIZER_NAME nsresult::NS_ERROR_XPC_BAD_INITIALIZER_NAME
#define NS_ERROR_XPC_HAS_BEEN_SHUTDOWN nsresult::NS_ERROR_XPC_HAS_BEEN_SHUTDOWN
#define NS_ERROR_XPC_CANT_MODIFY_PROP_ON_WN nsresult::NS_ERROR_XPC_CANT_MODIFY_PROP_ON_WN
#define NS_ERROR_XPC_BAD_CONVERT_JS_ZERO_ISNOT_NULL nsresult::NS_ERROR_XPC_BAD_CONVERT_JS_ZERO_ISNOT_NULL
#define NS_ERROR_XPC_CANT_PASS_CPOW_TO_NATIVE nsresult::NS_ERROR_XPC_CANT_PASS_CPOW_TO_NATIVE
#define NS_SUCCESS_I_DID_SOMETHING nsresult::NS_SUCCESS_I_DID_SOMETHING
#define NS_ERROR_LAUNCHED_CHILD_PROCESS nsresult::NS_ERROR_LAUNCHED_CHILD_PROCESS
#define NS_ERROR_CSP_FRAME_ANCESTOR_VIOLATION nsresult::NS_ERROR_CSP_FRAME_ANCESTOR_VIOLATION
#define NS_ERROR_CMS_VERIFY_NOT_SIGNED nsresult::NS_ERROR_CMS_VERIFY_NOT_SIGNED
#define NS_ERROR_CMS_VERIFY_NO_CONTENT_INFO nsresult::NS_ERROR_CMS_VERIFY_NO_CONTENT_INFO
#define NS_ERROR_CMS_VERIFY_BAD_DIGEST nsresult::NS_ERROR_CMS_VERIFY_BAD_DIGEST
#define NS_ERROR_CMS_VERIFY_NOCERT nsresult::NS_ERROR_CMS_VERIFY_NOCERT
#define NS_ERROR_CMS_VERIFY_UNTRUSTED nsresult::NS_ERROR_CMS_VERIFY_UNTRUSTED
#define NS_ERROR_CMS_VERIFY_ERROR_UNVERIFIED nsresult::NS_ERROR_CMS_VERIFY_ERROR_UNVERIFIED
#define NS_ERROR_CMS_VERIFY_ERROR_PROCESSING nsresult::NS_ERROR_CMS_VERIFY_ERROR_PROCESSING
#define NS_ERROR_CMS_VERIFY_BAD_SIGNATURE nsresult::NS_ERROR_CMS_VERIFY_BAD_SIGNATURE
#define NS_ERROR_CMS_VERIFY_DIGEST_MISMATCH nsresult::NS_ERROR_CMS_VERIFY_DIGEST_MISMATCH
#define NS_ERROR_CMS_VERIFY_UNKNOWN_ALGO nsresult::NS_ERROR_CMS_VERIFY_UNKNOWN_ALGO
#define NS_ERROR_CMS_VERIFY_UNSUPPORTED_ALGO nsresult::NS_ERROR_CMS_VERIFY_UNSUPPORTED_ALGO
#define NS_ERROR_CMS_VERIFY_MALFORMED_SIGNATURE nsresult::NS_ERROR_CMS_VERIFY_MALFORMED_SIGNATURE
#define NS_ERROR_CMS_VERIFY_HEADER_MISMATCH nsresult::NS_ERROR_CMS_VERIFY_HEADER_MISMATCH
#define NS_ERROR_CMS_VERIFY_NOT_YET_ATTEMPTED nsresult::NS_ERROR_CMS_VERIFY_NOT_YET_ATTEMPTED
#define NS_ERROR_CMS_VERIFY_CERT_WITHOUT_ADDRESS nsresult::NS_ERROR_CMS_VERIFY_CERT_WITHOUT_ADDRESS
#define NS_ERROR_CMS_ENCRYPT_NO_BULK_ALG nsresult::NS_ERROR_CMS_ENCRYPT_NO_BULK_ALG
#define NS_ERROR_CMS_ENCRYPT_INCOMPLETE nsresult::NS_ERROR_CMS_ENCRYPT_INCOMPLETE
#define NS_ERROR_DOM_INVALID_EXPRESSION_ERR nsresult::NS_ERROR_DOM_INVALID_EXPRESSION_ERR
#define NS_ERROR_DOM_TYPE_ERR nsresult::NS_ERROR_DOM_TYPE_ERR
#define NS_ERROR_WONT_HANDLE_CONTENT nsresult::NS_ERROR_WONT_HANDLE_CONTENT
#define NS_ERROR_MALWARE_URI nsresult::NS_ERROR_MALWARE_URI
#define NS_ERROR_PHISHING_URI nsresult::NS_ERROR_PHISHING_URI
#define NS_ERROR_SAVE_LINK_AS_TIMEOUT nsresult::NS_ERROR_SAVE_LINK_AS_TIMEOUT
#define NS_ERROR_PARSED_DATA_CACHED nsresult::NS_ERROR_PARSED_DATA_CACHED
#define NS_REFRESHURI_HEADER_FOUND nsresult::NS_REFRESHURI_HEADER_FOUND
#define NS_ERROR_IMAGE_SRC_CHANGED nsresult::NS_ERROR_IMAGE_SRC_CHANGED
#define NS_ERROR_IMAGE_BLOCKED nsresult::NS_ERROR_IMAGE_BLOCKED
#define NS_ERROR_CONTENT_BLOCKED nsresult::NS_ERROR_CONTENT_BLOCKED
#define NS_ERROR_CONTENT_BLOCKED_SHOW_ALT nsresult::NS_ERROR_CONTENT_BLOCKED_SHOW_ALT
#define NS_PROPTABLE_PROP_NOT_THERE nsresult::NS_PROPTABLE_PROP_NOT_THERE
#define NS_ERROR_XBL_BLOCKED nsresult::NS_ERROR_XBL_BLOCKED
#define NS_ERROR_CONTENT_CRASHED nsresult::NS_ERROR_CONTENT_CRASHED
#define NS_HTML_STYLE_PROPERTY_NOT_THERE nsresult::NS_HTML_STYLE_PROPERTY_NOT_THERE
#define NS_CONTENT_BLOCKED nsresult::NS_CONTENT_BLOCKED
#define NS_CONTENT_BLOCKED_SHOW_ALT nsresult::NS_CONTENT_BLOCKED_SHOW_ALT
#define NS_PROPTABLE_PROP_OVERWRITTEN nsresult::NS_PROPTABLE_PROP_OVERWRITTEN
#define NS_FINDBROADCASTER_NOT_FOUND nsresult::NS_FINDBROADCASTER_NOT_FOUND
#define NS_FINDBROADCASTER_FOUND nsresult::NS_FINDBROADCASTER_FOUND
#define NS_FINDBROADCASTER_AWAIT_OVERLAYS nsresult::NS_FINDBROADCASTER_AWAIT_OVERLAYS
#define NS_ERROR_XPATH_INVALID_ARG nsresult::NS_ERROR_XPATH_INVALID_ARG
#define NS_ERROR_XSLT_PARSE_FAILURE nsresult::NS_ERROR_XSLT_PARSE_FAILURE
#define NS_ERROR_XPATH_PARSE_FAILURE nsresult::NS_ERROR_XPATH_PARSE_FAILURE
#define NS_ERROR_XSLT_ALREADY_SET nsresult::NS_ERROR_XSLT_ALREADY_SET
#define NS_ERROR_XSLT_EXECUTION_FAILURE nsresult::NS_ERROR_XSLT_EXECUTION_FAILURE
#define NS_ERROR_XPATH_UNKNOWN_FUNCTION nsresult::NS_ERROR_XPATH_UNKNOWN_FUNCTION
#define NS_ERROR_XSLT_BAD_RECURSION nsresult::NS_ERROR_XSLT_BAD_RECURSION
#define NS_ERROR_XSLT_BAD_VALUE nsresult::NS_ERROR_XSLT_BAD_VALUE
#define NS_ERROR_XSLT_NODESET_EXPECTED nsresult::NS_ERROR_XSLT_NODESET_EXPECTED
#define NS_ERROR_XSLT_ABORTED nsresult::NS_ERROR_XSLT_ABORTED
#define NS_ERROR_XSLT_NETWORK_ERROR nsresult::NS_ERROR_XSLT_NETWORK_ERROR
#define NS_ERROR_XSLT_WRONG_MIME_TYPE nsresult::NS_ERROR_XSLT_WRONG_MIME_TYPE
#define NS_ERROR_XSLT_LOAD_RECURSION nsresult::NS_ERROR_XSLT_LOAD_RECURSION
#define NS_ERROR_XPATH_BAD_ARGUMENT_COUNT nsresult::NS_ERROR_XPATH_BAD_ARGUMENT_COUNT
#define NS_ERROR_XPATH_BAD_EXTENSION_FUNCTION nsresult::NS_ERROR_XPATH_BAD_EXTENSION_FUNCTION
#define NS_ERROR_XPATH_PAREN_EXPECTED nsresult::NS_ERROR_XPATH_PAREN_EXPECTED
#define NS_ERROR_XPATH_INVALID_AXIS nsresult::NS_ERROR_XPATH_INVALID_AXIS
#define NS_ERROR_XPATH_NO_NODE_TYPE_TEST nsresult::NS_ERROR_XPATH_NO_NODE_TYPE_TEST
#define NS_ERROR_XPATH_BRACKET_EXPECTED nsresult::NS_ERROR_XPATH_BRACKET_EXPECTED
#define NS_ERROR_XPATH_INVALID_VAR_NAME nsresult::NS_ERROR_XPATH_INVALID_VAR_NAME
#define NS_ERROR_XPATH_UNEXPECTED_END nsresult::NS_ERROR_XPATH_UNEXPECTED_END
#define NS_ERROR_XPATH_OPERATOR_EXPECTED nsresult::NS_ERROR_XPATH_OPERATOR_EXPECTED
#define NS_ERROR_XPATH_UNCLOSED_LITERAL nsresult::NS_ERROR_XPATH_UNCLOSED_LITERAL
#define NS_ERROR_XPATH_BAD_COLON nsresult::NS_ERROR_XPATH_BAD_COLON
#define NS_ERROR_XPATH_BAD_BANG nsresult::NS_ERROR_XPATH_BAD_BANG
#define NS_ERROR_XPATH_ILLEGAL_CHAR nsresult::NS_ERROR_XPATH_ILLEGAL_CHAR
#define NS_ERROR_XPATH_BINARY_EXPECTED nsresult::NS_ERROR_XPATH_BINARY_EXPECTED
#define NS_ERROR_XSLT_LOAD_BLOCKED_ERROR nsresult::NS_ERROR_XSLT_LOAD_BLOCKED_ERROR
#define NS_ERROR_XPATH_INVALID_EXPRESSION_EVALUATED nsresult::NS_ERROR_XPATH_INVALID_EXPRESSION_EVALUATED
#define NS_ERROR_XPATH_UNBALANCED_CURLY_BRACE nsresult::NS_ERROR_XPATH_UNBALANCED_CURLY_BRACE
#define NS_ERROR_XSLT_BAD_NODE_NAME nsresult::NS_ERROR_XSLT_BAD_NODE_NAME
#define NS_ERROR_XSLT_VAR_ALREADY_SET nsresult::NS_ERROR_XSLT_VAR_ALREADY_SET
#define NS_XSLT_GET_NEW_HANDLER nsresult::NS_XSLT_GET_NEW_HANDLER
#define NS_ERROR_DOM_SVG_WRONG_TYPE_ERR nsresult::NS_ERROR_DOM_SVG_WRONG_TYPE_ERR
#define NS_ERROR_DOM_SVG_MATRIX_NOT_INVERTABLE nsresult::NS_ERROR_DOM_SVG_MATRIX_NOT_INVERTABLE
#define NS_ERROR_STORAGE_BUSY nsresult::NS_ERROR_STORAGE_BUSY
#define NS_ERROR_STORAGE_IOERR nsresult::NS_ERROR_STORAGE_IOERR
#define NS_ERROR_STORAGE_CONSTRAINT nsresult::NS_ERROR_STORAGE_CONSTRAINT
#define NS_ERROR_DOM_FILE_NOT_FOUND_ERR nsresult::NS_ERROR_DOM_FILE_NOT_FOUND_ERR
#define NS_ERROR_DOM_FILE_NOT_READABLE_ERR nsresult::NS_ERROR_DOM_FILE_NOT_READABLE_ERR
#define NS_ERROR_DOM_FILE_ABORT_ERR nsresult::NS_ERROR_DOM_FILE_ABORT_ERR
#define NS_ERROR_DOM_INDEXEDDB_UNKNOWN_ERR nsresult::NS_ERROR_DOM_INDEXEDDB_UNKNOWN_ERR
#define NS_ERROR_DOM_INDEXEDDB_NOT_FOUND_ERR nsresult::NS_ERROR_DOM_INDEXEDDB_NOT_FOUND_ERR
#define NS_ERROR_DOM_INDEXEDDB_CONSTRAINT_ERR nsresult::NS_ERROR_DOM_INDEXEDDB_CONSTRAINT_ERR
#define NS_ERROR_DOM_INDEXEDDB_DATA_ERR nsresult::NS_ERROR_DOM_INDEXEDDB_DATA_ERR
#define NS_ERROR_DOM_INDEXEDDB_NOT_ALLOWED_ERR nsresult::NS_ERROR_DOM_INDEXEDDB_NOT_ALLOWED_ERR
#define NS_ERROR_DOM_INDEXEDDB_TRANSACTION_INACTIVE_ERR nsresult::NS_ERROR_DOM_INDEXEDDB_TRANSACTION_INACTIVE_ERR
#define NS_ERROR_DOM_INDEXEDDB_ABORT_ERR nsresult::NS_ERROR_DOM_INDEXEDDB_ABORT_ERR
#define NS_ERROR_DOM_INDEXEDDB_READ_ONLY_ERR nsresult::NS_ERROR_DOM_INDEXEDDB_READ_ONLY_ERR
#define NS_ERROR_DOM_INDEXEDDB_TIMEOUT_ERR nsresult::NS_ERROR_DOM_INDEXEDDB_TIMEOUT_ERR
#define NS_ERROR_DOM_INDEXEDDB_QUOTA_ERR nsresult::NS_ERROR_DOM_INDEXEDDB_QUOTA_ERR
#define NS_ERROR_DOM_INDEXEDDB_VERSION_ERR nsresult::NS_ERROR_DOM_INDEXEDDB_VERSION_ERR
#define NS_ERROR_DOM_INDEXEDDB_RECOVERABLE_ERR nsresult::NS_ERROR_DOM_INDEXEDDB_RECOVERABLE_ERR
#define NS_ERROR_DOM_FILEHANDLE_UNKNOWN_ERR nsresult::NS_ERROR_DOM_FILEHANDLE_UNKNOWN_ERR
#define NS_ERROR_DOM_FILEHANDLE_NOT_ALLOWED_ERR nsresult::NS_ERROR_DOM_FILEHANDLE_NOT_ALLOWED_ERR
#define NS_ERROR_DOM_FILEHANDLE_LOCKEDFILE_INACTIVE_ERR nsresult::NS_ERROR_DOM_FILEHANDLE_LOCKEDFILE_INACTIVE_ERR
#define NS_ERROR_DOM_FILEHANDLE_ABORT_ERR nsresult::NS_ERROR_DOM_FILEHANDLE_ABORT_ERR
#define NS_ERROR_DOM_FILEHANDLE_READ_ONLY_ERR nsresult::NS_ERROR_DOM_FILEHANDLE_READ_ONLY_ERR
#define NS_ERROR_DOM_FILEHANDLE_QUOTA_ERR nsresult::NS_ERROR_DOM_FILEHANDLE_QUOTA_ERR
#define NS_ERROR_SIGNED_JAR_NOT_SIGNED nsresult::NS_ERROR_SIGNED_JAR_NOT_SIGNED
#define NS_ERROR_SIGNED_JAR_MODIFIED_ENTRY nsresult::NS_ERROR_SIGNED_JAR_MODIFIED_ENTRY
#define NS_ERROR_SIGNED_JAR_UNSIGNED_ENTRY nsresult::NS_ERROR_SIGNED_JAR_UNSIGNED_ENTRY
#define NS_ERROR_SIGNED_JAR_ENTRY_MISSING nsresult::NS_ERROR_SIGNED_JAR_ENTRY_MISSING
#define NS_ERROR_SIGNED_JAR_WRONG_SIGNATURE nsresult::NS_ERROR_SIGNED_JAR_WRONG_SIGNATURE
#define NS_ERROR_SIGNED_JAR_ENTRY_TOO_LARGE nsresult::NS_ERROR_SIGNED_JAR_ENTRY_TOO_LARGE
#define NS_ERROR_SIGNED_JAR_ENTRY_INVALID nsresult::NS_ERROR_SIGNED_JAR_ENTRY_INVALID
#define NS_ERROR_SIGNED_JAR_MANIFEST_INVALID nsresult::NS_ERROR_SIGNED_JAR_MANIFEST_INVALID
#define NS_ERROR_DOM_FILESYSTEM_INVALID_PATH_ERR nsresult::NS_ERROR_DOM_FILESYSTEM_INVALID_PATH_ERR
#define NS_ERROR_DOM_FILESYSTEM_INVALID_MODIFICATION_ERR nsresult::NS_ERROR_DOM_FILESYSTEM_INVALID_MODIFICATION_ERR
#define NS_ERROR_DOM_FILESYSTEM_NO_MODIFICATION_ALLOWED_ERR nsresult::NS_ERROR_DOM_FILESYSTEM_NO_MODIFICATION_ALLOWED_ERR
#define NS_ERROR_DOM_FILESYSTEM_PATH_EXISTS_ERR nsresult::NS_ERROR_DOM_FILESYSTEM_PATH_EXISTS_ERR
#define NS_ERROR_DOM_FILESYSTEM_TYPE_MISMATCH_ERR nsresult::NS_ERROR_DOM_FILESYSTEM_TYPE_MISMATCH_ERR
#define NS_ERROR_DOM_FILESYSTEM_UNKNOWN_ERR nsresult::NS_ERROR_DOM_FILESYSTEM_UNKNOWN_ERR
#define NS_ERROR_DOWNLOAD_COMPLETE nsresult::NS_ERROR_DOWNLOAD_COMPLETE
#define NS_ERROR_DOWNLOAD_NOT_PARTIAL nsresult::NS_ERROR_DOWNLOAD_NOT_PARTIAL
#define NS_ERROR_UNORM_MOREOUTPUT nsresult::NS_ERROR_UNORM_MOREOUTPUT
#define NS_ERROR_DOCSHELL_REQUEST_REJECTED nsresult::NS_ERROR_DOCSHELL_REQUEST_REJECTED
#define NS_ERROR_DOCUMENT_IS_PRINTMODE nsresult::NS_ERROR_DOCUMENT_IS_PRINTMODE
#define NS_SUCCESS_DONT_FIXUP nsresult::NS_SUCCESS_DONT_FIXUP
#define NS_SUCCESS_RESTART_APP nsresult::NS_SUCCESS_RESTART_APP
#define NS_SUCCESS_RESTART_METRO_APP nsresult::NS_SUCCESS_RESTART_METRO_APP
#define NS_SUCCESS_UNORM_NOTFOUND nsresult::NS_SUCCESS_UNORM_NOTFOUND
#define NS_ERROR_NOT_IN_TREE nsresult::NS_ERROR_NOT_IN_TREE
#define NS_OK_NO_NAME_CLAUSE_HANDLED nsresult::NS_OK_NO_NAME_CLAUSE_HANDLED
